import os as _os
_base = _os.path.dirname(__file__)
for _root, _dirs, _files in _os.walk(_base):
    _dirs[:] = sorted(d for d in _dirs if not d.startswith((".", "_")))
    if _root != _base:
        __path__.append(_root)

"""Wisent error handling module."""

from .error_codes import (
    ErrorCode,
    ERROR_MESSAGES,
    WisentError,
    # Data Loading Errors
    TaskLoadError,
    TaskNotFoundError,
    FallbackNotPermittedError,
    NoDocsAvailableError,
    DatasetLoadError,
    VersionValidationError,
    VersionInfoError,
    BenchmarkLoadError,
    FileLoadError,
    InvalidJSONError,
    InvalidDataFormatError,
    GroupExpansionError,
    # Evaluation Errors
    EvaluationError,
    ExactMatchError,
    BigCodeEvaluationError,
    TaskNameRequiredError,
    NumericalExtractionError,
    TextExtractionError,
    ExtractorNotFoundError,
    ExtractorReturnedNoneError,
    BigCodeTaskRequiresFlagError,
    # Model/Chat Errors
    ChatTemplateNotAvailableError,
    ChatTemplateError,
    EmptyGenerationError,
    TokenizerMissingMethodError,
    ModelArchitectureUnknownError,
    DecoderLayersNotFoundError,
    HiddenSizeNotFoundError,
    NoHiddenStatesError,
    LayerNotFoundError,
    ModelConfigAccessError,
    # Configuration/Validation Errors
    MissingParameterError,
    InvalidChoicesError,
    ModelNotProvidedError,
    InvalidRangeError,
    InvalidValueError,
    DuplicateNameError,
    UnknownTypeError,
    InsufficientDataError,
    LayerRangeError,
    # Agent/Diagnostic Errors
    ClassifierLoadError,
    ClassifierCreationError,
    NoQualityScoresError,
    NoConfidenceScoresError,
    ClassifierConfigRequiredError,
    DeviceBenchmarkError,
    BudgetCalculationError,
    ResourceEstimationError,
    NoBenchmarkDataError,
    TrainingDataGenerationError,
    NoSuitableClassifierError,
    ImprovementMethodUnknownError,
    # Steering/Training Errors
    SteeringMethodUnknownError,
    NoTrainingResultError,
    ControlVectorDiagnosticsError,
    NoTrainedVectorsError,
    SteeringTrainerNotFoundError,
    InvalidLayerIdError,
    NoCandidateLayersError,
    OptimizationError,
    VectorQualityTooLowError,
    # Contrastive Pairs Errors
    PairGenerationError,
    InvalidPairStructureError,
    NoActivationDataError,
    PairDiagnosticsError,
    PromptMustBeStringError,
    ResponseMustBeStringError,
    # Docker/Runtime Errors
    DockerRuntimeError,
    ContainerNotRunningError,
    ExecutionError,
    # Calibration/Timing Errors
    CalibrationError,
    CalibrationDataMissingError,
    CalibrationDataInvalidError,
    CalibrationRequiredError,
    # Serialization Errors
    DecodeError,
    InvalidJSONStructureError,
    MissingRequiredFieldError,
    # Multimodal Errors
    NoWaveformDataError,
    NoPixelDataError,
    NoFrameDataError,
    NoStateDataError,
    NoActionDataError,
    EmptyTrajectoryError,
    MultimodalContentRequiredError,
)

__all__ = [
    "ErrorCode",
    "ERROR_MESSAGES",
    "WisentError",
    # Data Loading Errors
    "TaskLoadError",
    "TaskNotFoundError",
    "FallbackNotPermittedError",
    "NoDocsAvailableError",
    "DatasetLoadError",
    "VersionValidationError",
    "VersionInfoError",
    "BenchmarkLoadError",
    "FileLoadError",
    "InvalidJSONError",
    "InvalidDataFormatError",
    "GroupExpansionError",
    # Evaluation Errors
    "EvaluationError",
    "ExactMatchError",
    "BigCodeEvaluationError",
    "TaskNameRequiredError",
    "NumericalExtractionError",
    "TextExtractionError",
    "ExtractorNotFoundError",
    "ExtractorReturnedNoneError",
    "BigCodeTaskRequiresFlagError",
    # Model/Chat Errors
    "ChatTemplateNotAvailableError",
    "ChatTemplateError",
    "EmptyGenerationError",
    "TokenizerMissingMethodError",
    "ModelArchitectureUnknownError",
    "DecoderLayersNotFoundError",
    "HiddenSizeNotFoundError",
    "NoHiddenStatesError",
    "LayerNotFoundError",
    "ModelConfigAccessError",
    # Configuration/Validation Errors
    "MissingParameterError",
    "InvalidChoicesError",
    "ModelNotProvidedError",
    "InvalidRangeError",
    "InvalidValueError",
    "DuplicateNameError",
    "UnknownTypeError",
    "InsufficientDataError",
    "LayerRangeError",
    # Agent/Diagnostic Errors
    "ClassifierLoadError",
    "ClassifierCreationError",
    "NoQualityScoresError",
    "NoConfidenceScoresError",
    "ClassifierConfigRequiredError",
    "DeviceBenchmarkError",
    "BudgetCalculationError",
    "ResourceEstimationError",
    "NoBenchmarkDataError",
    "TrainingDataGenerationError",
    "NoSuitableClassifierError",
    "ImprovementMethodUnknownError",
    # Steering/Training Errors
    "SteeringMethodUnknownError",
    "NoTrainingResultError",
    "ControlVectorDiagnosticsError",
    "NoTrainedVectorsError",
    "SteeringTrainerNotFoundError",
    "InvalidLayerIdError",
    "NoCandidateLayersError",
    "OptimizationError",
    "VectorQualityTooLowError",
    # Contrastive Pairs Errors
    "PairGenerationError",
    "InvalidPairStructureError",
    "NoActivationDataError",
    "PairDiagnosticsError",
    "PromptMustBeStringError",
    "ResponseMustBeStringError",
    # Docker/Runtime Errors
    "DockerRuntimeError",
    "ContainerNotRunningError",
    "ExecutionError",
    # Calibration/Timing Errors
    "CalibrationError",
    "CalibrationDataMissingError",
    "CalibrationDataInvalidError",
    "CalibrationRequiredError",
    # Serialization Errors
    "DecodeError",
    "InvalidJSONStructureError",
    "MissingRequiredFieldError",
    # Multimodal Errors
    "NoWaveformDataError",
    "NoPixelDataError",
    "NoFrameDataError",
    "NoStateDataError",
    "NoActionDataError",
    "EmptyTrajectoryError",
    "MultimodalContentRequiredError",
]
