"""Flores group task manifest - Part 2 (F-Z language pairs)."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

FLORES_TASKS_PART2 = {
    "flores_eng_Latn-taq_Tfng_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Tfng_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-taq_Tfng_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tir_Ethi_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tir_Ethi_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tir_Ethi_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tsn_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tsn_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tsn_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tso_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tso_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tso_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tum_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tum_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tum_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-twi_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-twi_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-twi_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tzm_Tfng_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tzm_Tfng_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-tzm_Tfng_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-umb_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-umb_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-umb_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-wol_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-wol_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-wol_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-xho_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-xho_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-xho_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-yor_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-yor_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-yor_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-zul_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-zul_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eng_Latn-zul_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_es-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_eu-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ewe_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ewe_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ewe_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fon_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fon_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fon_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fr-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fra_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fra_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fra_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fuv_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fuv_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_fuv_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gaz_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gaz_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gaz_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_gl-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_hau_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_hau_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_hau_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ibo_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ibo_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ibo_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_it-pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kab_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kab_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kab_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kam_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kam_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kam_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kbp_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kbp_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kbp_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kea_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kea_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kea_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kik_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kik_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kik_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kin_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kin_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kin_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kmb_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kmb_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kmb_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Arab-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Arab-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Arab-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_knc_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kon_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kon_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_kon_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lin_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lin_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lin_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lua_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lua_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lua_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lug_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lug_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_lug_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_luo_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_luo_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_luo_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_mos_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_mos_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_mos_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nso_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nso_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nso_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nus_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nus_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nus_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nya_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nya_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_nya_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_plt_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_plt_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_plt_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-ca": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-de": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-en": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-es": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-eu": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-fr": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-gl": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_pt-it": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_run_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_run_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_run_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sag_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sag_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sag_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sna_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sna_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sna_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_som_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_som_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_som_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sot_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sot_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sot_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ssw_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ssw_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_ssw_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sun_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sun_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_sun_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_swh_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_swh_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_swh_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Tfng-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Tfng-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_taq_Tfng-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tir_Ethi-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tir_Ethi-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tir_Ethi-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tsn_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tsn_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tsn_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tso_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tso_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tso_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tum_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tum_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tum_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_twi_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_twi_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_twi_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tzm_Tfng-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tzm_Tfng-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_tzm_Tfng-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_umb_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_umb_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_umb_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_wol_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_wol_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_wol_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_xho_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_xho_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_xho_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_yor_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_yor_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_yor_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_zul_Latn-eng_Latn_prompt_1": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_zul_Latn-eng_Latn_prompt_2": f"{BASE_IMPORT}flores:FloresExtractor",
    "flores_zul_Latn-eng_Latn_prompt_3": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_all_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_dr_en_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_dr_fr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_dr_msa_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_en_dr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_fr_dr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
    "trasnlation_msa_dr_flores": f"{BASE_IMPORT}flores:FloresExtractor",
}
